@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2019 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2020 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by
@@ -25,8 +25,8 @@
 
 #include <QMap>
 #include <QTimer>
-#include <kcolorscheme.h>
-#include <kcompletionbox.h>
+#include <KColorScheme>
+#include <KCompletionBox>
 #include <AkonadiCore/Session>
 #include <Akonadi/Contact/ContactSearchJob>
 #include <Akonadi/Contact/ContactGroupSearchJob>
@@ -296,7 +296,7 @@ const QStringList KPIM::AddresseeLineEditPrivate::adjustedCompletionItems(bool f
                 lastSourceIndex = index;
             }
 
-            (*it) = (*it).prepend(s_completionItemIndentString);
+            (*it).prepend(s_completionItemIndentString);
             // remove preferred email sort <blank> added in  addContact()
             (*it).replace(QLatin1String("  <"), QStringLiteral(" <"));
         }
@@ -558,7 +558,7 @@ void AddresseeLineEditPrivate::doCompletion(bool ctrlT)
                     }
                 } else if (mSearchExtended) {
                     //our added \" does not work anymore, remove it
-                    mSearchString = mSearchString.mid(1);
+                    mSearchString.remove(0, 1);
                     mSearchExtended = false;
                     q->setText(mPreviousAddresses + mSearchString);
                     //now try again
