@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2017-2018 Laurent Montel <montel@kde.org>
+   Copyright (C) 2017-2020 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -22,9 +22,7 @@
 
 using namespace KPIM;
 
-AddresseeLineEditAkonadi::AddresseeLineEditAkonadi(AddresseeLineEditManager *addressLineStatic)
-    : m_akonadiSession(nullptr)
-    , mAddressLineStatic(addressLineStatic)
+AddresseeLineEditAkonadi::AddresseeLineEditAkonadi()
 {
 }
 
