@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2017-2018 Laurent Montel <montel@kde.org>
+   Copyright (C) 2017-2020 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -21,7 +21,7 @@
 #include "addressesslineeditabstractplugin.h"
 #include "libkdepimakonadi_debug.h"
 
-#include <kpluginmetadata.h>
+#include <KPluginMetaData>
 #include <KPluginLoader>
 #include <KPluginFactory>
 
@@ -71,9 +71,7 @@ bool AddressessLineEditPluginManagerPrivate::initializePlugins()
     if (!mPluginList.isEmpty()) {
         return true;
     }
-    const QVector<KPluginMetaData> plugins = KPluginLoader::findPlugins(QStringLiteral("addressline"), [](const KPluginMetaData &md) {
-        return md.serviceTypes().contains(QLatin1String("AddressLineEdit/Plugin"));
-    });
+    const QVector<KPluginMetaData> plugins = KPluginLoader::findPlugins(QStringLiteral("addressline"));
 
     QVectorIterator<KPluginMetaData> i(plugins);
     i.toBack();
@@ -147,8 +145,10 @@ QVector<KPIM::AddressessLineEditAbstractPlugin *> AddressessLineEditPluginManage
 
 KPIM::AddressessLineEditAbstractPlugin *AddressessLineEditPluginManager::plugin(const QString &identifier)
 {
-    for (KPIM::AddressessLineEditAbstractPlugin *p : pluginsList()) {
-        for (const AddressessLineEditAbstractPluginInfo &info : p->names()) {
+    const QVector<KPIM::AddressessLineEditAbstractPlugin *> lstPlugins = pluginsList();
+    for (KPIM::AddressessLineEditAbstractPlugin *p : lstPlugins) {
+        const QVector<AddressessLineEditAbstractPluginInfo> lstPluginsInfo = p->names();
+        for (const AddressessLineEditAbstractPluginInfo &info : lstPluginsInfo) {
             if (info.identifier == identifier) {
                 return p;
             }
