@@ -24,8 +24,7 @@
 #include "progressmanagerakonadi.h"
 #include "agentprogressmonitor.h"
 
-KPIM::ProgressItem *KPIM::ProgressManagerAkonadi::createProgressItem(ProgressItem *parent, const Akonadi::AgentInstance &agent, const QString &id, const QString &label, const QString &status,
-                                                                     bool canBeCanceled, ProgressItem::CryptoStatus cryptoStatus)
+KPIM::ProgressItem *KPIM::ProgressManagerAkonadi::createProgressItem(ProgressItem *parent, const Akonadi::AgentInstance &agent, const QString &id, const QString &label, const QString &status, bool canBeCanceled, ProgressItem::CryptoStatus cryptoStatus)
 {
     const bool itemAlreadyExists = (KPIM::ProgressManager::instance()->progressItem(id) != nullptr);
     KPIM::ProgressItem *t = KPIM::ProgressManager::instance()->createProgressItem(parent, id, label,
